#
# spec file for package materia-gtk-theme
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name    materia-theme
Name:           materia-gtk-theme
Version:        20210322
Release:        1.10
Summary:        A Material Design theme for GNOME/GTK+ based desktop environments
License:        GPL-2.0-only
URL:            https://github.com/nana-4/materia-theme
Source:         https://github.com/nana-4/%{_name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  sassc
Requires:       gnome-themes-extras
Recommends:     gtk2-engine-murrine
BuildArch:      noarch

%description
Materia (formerly Flat-Plat) is a Material Design theme for GNOME/GTK+ based desktop environments.
It supports GTK+ 3, GTK+ 2, GNOME Shell, Budgie, Cinnamon, MATE, Unity, LightDM, GDM, Chrome theme, etc.

%prep
%autosetup -n %{_name}-%{version}

%build
%meson
%meson_build

%install
%meson_install

%fdupes %{buildroot}

#fix permissions
find %{buildroot}/%{_datadir}/themes -type f -exec chmod -x {} \;
#remove duplicate COPYING files
find %{buildroot}%{_datadir}/themes -name COPYING -delete

%files
%license COPYING
%doc README.md
%{_datadir}/themes/*

%changelog
* Tue Apr 20 2021 Nianqing Yao <imbearchild@outlook.com>
- Update to version 20210322
  * Add support for GTK 4
  * Add support for gnome-shell 40
  * Update color scheme
  * Make dark theme darker
  * Update scrollbar slider colors
  * gtk3: Change background/surface rule
  * gtk3: Drop undershoot styling
  * gtk3/assistant: Change highlighted label style in sidebar
  * gtk3: Tone down hover overlay in some widgets
  * gtk3: Drop transparency from overlay scrollbars
  * gtk3: Change the direction of the expander arrow
  * gtk3/combobox: Update the arrow button style
  * gtk3: Make checked flat button blue
  * gtk3/pathbar: Make checked button's text/ink color blue
  * gtk3: Update stacksidebar style
  * gtk3: Update notebook style
  * gtk3: Update .keycap style
  * gtk3: Update focus entry style
  * cinnamon & gnome-shell: Revamp drop shadows
  * gnome-shell: Update app folder icon style
  * meson: Allow specifying micro version in the build option `gnome_shell_version`
  * meson: Avoid copying configured SCSS files to current_source_dir()
  * Other various minor improvements and fixes
* Sun Dec 27 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 20200916
  * Add Meson build system
  * Drop pre-generated CSS files
  * Add sassc dependency
  * Drop bc dependency
  * Improve source file structure
  * gtk: Add initial support for libhandy
  * gnome-shell: Add support for version 3.38
  * gnome-shell: Update calendar style to match Material Design guideline
  * metacity/unity/xfwm: Update title bars to match the last GTK changes
  * chrome theme: Improve and simplify
  * Other various improvements and fixes
* Fri May 29 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 20200320
  * Make dark variant even darker
  * Don't change button text color on focus, hover, active
  * gtk: Rewrite ripple implementation
  * gtk: Change checked raised button style
  * gtk: Lighten up switch slider color on dark variant
  * gtk: Use primary color for spinner
  * gtk: Use primary color for caret-color (experimentally)
  * gtk: Add various improvements of Budgie styling
  * gnome-shell: Add support for version 3.36
  * gnome-shell: Drop support for versions 3.18 - 3.24
  * gnome-shell: Drop support for legacy Ubuntu-specific sessions
  * gnome-shell: Land massive Sass rewrite
  * Other various improvements, fixes, refactors, and cleanups
* Fri Mar 15 2019 Matthias Eliasson <elimat@opensuse.org>
- Update to version 20190315
  * Add support for GNOME 3.32
  * Various improvements of source Sass code
* Sat Feb  2 2019 Matthias Eliasson <matthias.eliasson@gmail.com>
- Update to version 20190201
  * Added support for Plank
  * Added support for Xfce >=4.13
  * Dropped support for Budgie <10.4
  * Dropped (teal) secondary color
  * Changed entry style (as per refreshed Material Design Guidelines)
  * Changed combo button style (as per refreshed Material Design Guidelines)
  * Changed selected state style (as per refreshed Material Design Guidelines)
  * Changed sidebar style (as per refreshed Material Design Guidelines)
  * Changed headerbar's separator style
  * Tweaked button colors
  * Changed progress bar background-color to neutral gray
  * Changed disabled check/radio colors
  * Dropped excessive check/radio animations
  * budgie: Changed raven's tab bar colors
  * gnome-shell: Fixed .workspace-thumbnail-indicator position
  * gnome-shell: Tweaked transitions
  * Applied various style improvements for Budgie and Cinnamon
* Tue Dec 11 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Fix typo in source url
* Sun Dec  2 2018 Matthias Eliasson <matthias.eliasson@gmail.com>
- Initial package of version 20181125
